This module is a Facade to simplify usage of the
Gtk.TreeView with Gtk.ListStore model.

The module creates the ListStore model and initialises it
with the required columns and cell renderers.

The information as to the required columns and cell renderers
is specified as a list of tuples in the calling module.
